@@ -1,15 +1,95 @@
 package DBIx::Class::QueryLog::Analyzer;
-use Moose;
+$DBIx::Class::QueryLog::Analyzer::VERSION = '1.004000';
+# ABSTRACT: Query Analysis
+
+use Moo;
+use Types::Standard 'InstanceOf';
 
 has querylog => (
     is => 'rw',
-    isa => 'DBIx::Class::QueryLog'
+    isa => InstanceOf['DBIx::Class::QueryLog']
 );
 
+
+sub get_sorted_queries {
+    my ($self) = @_;
+
+    my @queries;
+
+    foreach my $l (@{ $self->querylog->log }) {
+        push(@queries, @{ $l->get_sorted_queries });
+    }
+    return [ reverse sort { $a->time_elapsed <=> $b->time_elapsed } @queries ];
+}
+
+sub get_fastest_query_executions {
+    my ($self, $sql) = @_;
+
+    my @queries;
+    foreach my $l (@{ $self->querylog->log }) {
+        push(@queries, @{ $l->get_sorted_queries($sql) });
+    }
+
+    return [ sort { $a->time_elapsed <=> $b->time_elapsed } @queries ];
+}
+
+
+sub get_slowest_query_executions {
+    my ($self, $sql) = @_;
+
+    return [ reverse @{ $self->get_fastest_query_executions($sql) } ];
+}
+
+
+sub get_totaled_queries {
+    my ($self, $honor_buckets) = @_;
+
+    my %totaled;
+    foreach my $l (@{ $self->querylog->log }) {
+        foreach my $q (@{ $l->queries }) {
+            if($honor_buckets) {
+                return $self->get_totaled_queries_by_bucket;
+            } else {
+                $totaled{$q->sql}->{count}++;
+                $totaled{$q->sql}->{time_elapsed} += $q->time_elapsed;
+                push(@{ $totaled{$q->sql}->{queries} }, $q);
+            }
+        }
+    }
+    return \%totaled;
+}
+
+
+sub get_totaled_queries_by_bucket {
+    my ($self) = @_;
+
+    my %totaled;
+    foreach my $l (@{ $self->querylog->log }) {
+        foreach my $q (@{ $l->queries }) {
+            $totaled{$q->bucket}->{$q->sql}->{count}++;
+            $totaled{$q->bucket}->{$q->sql}->{time_elapsed} += $q->time_elapsed;
+            push(@{ $totaled{$q->bucket}->{$q->sql}->{queries} }, $q);
+        }
+    }
+    return \%totaled;
+}
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 DBIx::Class::QueryLog::Analyzer - Query Analysis
 
+=head1 VERSION
+
+version 1.004000
+
 =head1 SYNOPSIS
 
 Analyzes the results of a QueryLog.  Create an Analyzer and pass it the
@@ -25,7 +105,6 @@ QueryLog:
     # or...
     my $totaled = $ana->get_totaled_queries;
 
-
 =head1 METHODS
 
 =head2 new
@@ -36,19 +115,6 @@ Create a new DBIx::Class::QueryLog::Analyzer
 
 Returns an arrayref of all Query objects, sorted by elapsed time (descending).
 
-=cut
-
-sub get_sorted_queries {
-    my ($self) = @_;
-
-    my @queries;
-
-    foreach my $l (@{ $self->querylog->log }) {
-        push(@queries, @{ $l->get_sorted_queries });
-    }
-    return [ reverse sort { $a->time_elapsed <=> $b->time_elapsed } @queries ];
-}
-
 =head2 get_fastest_query_executions($sql_statement)
 
 Returns an arrayref of Query objects representing in order of the fastest
@@ -58,30 +124,10 @@ SQL, including placeholders.
 
   $ana->get_slowest_query_executions("SELECT foo FROM bar WHERE gorch = ?");
 
-=cut
-sub get_fastest_query_executions {
-    my ($self, $sql) = @_;
-
-    my @queries;
-    foreach my $l (@{ $self->querylog->log }) {
-        push(@queries, @{ $l->get_sorted_queries($sql) });
-    }
-
-    return [ sort { $a->time_elapsed <=> $b->time_elapsed } @queries ];
-}
-
 =head2 get_slowest_query_executions($sql_statement)
 
 Opposite of I<get_fastest_query_executions>.  Same arguments.
 
-=cut
-
-sub get_slowest_query_executions {
-    my ($self, $sql) = @_;
-
-    return [ reverse @{ $self->get_fastest_query_executions($sql) } ];
-}
-
 =head2 get_totaled_queries
 
 Returns hashref of the queries executed, with same-SQL combined and totaled.
@@ -103,7 +149,7 @@ This is useful for when you've fine-tuned individually slow queries and need
 to isolate which queries are executed a lot, so that you can determine which
 to focus on next.
 
-To sort it you'll want to use something like this (sorry for the long line, 
+To sort it you'll want to use something like this (sorry for the long line,
 blame perl...):
 
     my $analyzed = $ana->get_totaled_queries;
@@ -113,26 +159,6 @@ blame perl...):
 
 So one could sort by count or time_elapsed.
 
-=cut
-
-sub get_totaled_queries {
-    my ($self, $honor_buckets) = @_;
-
-    my %totaled;
-    foreach my $l (@{ $self->querylog->log }) {
-        foreach my $q (@{ $l->queries }) {
-            if($honor_buckets) {
-                return $self->get_totaled_queries_by_bucket;
-            } else {
-                $totaled{$q->sql}->{count}++;
-                $totaled{$q->sql}->{time_elapsed} += $q->time_elapsed;
-                push(@{ $totaled{$q->sql}->{queries} }, $q);
-            }
-        }
-    }
-    return \%totaled;
-}
-
 =head2 get_totaled_queries_by_bucket
 
 Same as get_totaled_queries, but breaks the totaled queries up by bucket:
@@ -153,37 +179,25 @@ $var = {
 
 It is otherwise identical to get_totaled_queries
 
-=cut
+=head1 AUTHORS
 
-sub get_totaled_queries_by_bucket {
-    my ($self) = @_;
+=over 4
 
-    my %totaled;
-    foreach my $l (@{ $self->querylog->log }) {
-        foreach my $q (@{ $l->queries }) {
-            $totaled{$q->bucket}->{$q->sql}->{count}++;
-            $totaled{$q->bucket}->{$q->sql}->{time_elapsed} += $q->time_elapsed;
-            push(@{ $totaled{$q->bucket}->{$q->sql}->{queries} }, $q);
-        }
-    }
-    return \%totaled;
-}
+=item *
 
-=head1 AUTHOR
+Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
-Cory G Watson C<< <gphat at cpan.org> >>
+=item *
 
-=head1 ACKNOWLEDGEMENTS
+Cory G Watson <gphat at cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=back
 
-Copyright 2009 Cory G Watson, all rights reserved.
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2015 by Cory G Watson <gphat at cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__PACKAGE__->meta->make_immutable;
-
-1;
